@@ -294,7 +294,7 @@ XsldbgDriver::parseMarker()
 
     // TRACE("parseMarker : xsldbg");
     //  TRACE(m_output);
-    int len, markerStart = -1;
+    int len = 0, markerStart = -1;
     char *p = m_output;
 
     while (markerStart == -1) {
@@ -303,13 +303,16 @@ XsldbgDriver::parseMarker()
             return;
         }
         //TRACE(TQString("parseMarker is looking at :") + p);
-        markerStart = m_markerRE.match(p, 0, &len);
+        markerStart = m_markerRE.search(p, 0);
         if (markerStart == -1) {
             // try to marker on next line !
             p = strchr(p, '\n');
             if ((p != 0) && (*p != '\0'))
                 p++;
         }
+        else {
+            len = m_markerRE.matchedLength();
+        }
     }
 
 
@@ -327,7 +330,7 @@ XsldbgDriver::parseMarker()
     // extract filename and line number
     static TQRegExp MarkerRE(" at line [0-9]+");
 
-    int lineNoStart = MarkerRE.match(startMarker, 0, &len);
+    int lineNoStart = MarkerRE.search(startMarker, 0);
 
     if (lineNoStart >= 0) {
         int lineNo = atoi(startMarker + lineNoStart + 8);
@@ -1317,7 +1320,7 @@ XsldbgDriver::parseChangeExecutable(const char *output, TQString & message)
      * message (no debugging symbols found)...
      */
     TQRegExp exp(".*Load of source deferred. Use the run command.*");
-    int len, index = exp.match(output, 0, &len);
+    int index = exp.search(output, 0);
 
     if (index != -1) {
         TRACE("Parsed stylesheet executable");
@@ -1332,7 +1335,7 @@ XsldbgDriver::parseCoreFile(const char *output)
     TRACE("XsldbgDriver::parseCoreFile");
     TRACE(output);
     TQRegExp exp(".*Load of data file deferred. Use the run command.*");
-    int len, index = exp.match(output, 0, &len);
+    int index = exp.search(output, 0);
 
     if (index != -1) {
         m_haveCoreFile = true;
